<?PHP
       //Based on lib.php of the assignment module

require_once("$CFG->dirroot/files/mimetypes.php");

define("NEW_OFFLINE",      "0");
define("NEW_UPLOADSINGLE", "1");

$newassignment_TYPE = array (NEW_OFFLINE => get_string("typeoffline", "newassignment"),
                             NEW_UPLOADSINGLE  => get_string("typeuploadsingle", "newassignment") );

if (!isset($CFG->newassignment_maxbytes)) {
    set_config("newassignment_maxbytes", 1024000);  // Default maximum size for all newassignments
} 


function newassignment_add_instance($newassignment) {
// Given an object containing all the necessary data, 
// (defined by the form in mod.html) this function 
// will create a new instance and return the id number 
// of the new instance.

    $newassignment->timemodified = time();
    
    $newassignment->timedue = make_timestamp($newassignment->dueyear, $newassignment->duemonth, $newassignment->dueday, 
                                          $newassignment->duehour, $newassignment->dueminute);

    if ($returnid = insert_record("newassignment", $newassignment)) {
    
        $event = NULL;
        $event->name        = $newassignment->name;
        $event->description = $newassignment->description;
        $event->courseid    = $newassignment->course;
        $event->groupid     = 0;
        $event->userid      = 0;
        $event->modulename  = 'newassignment';
        $event->instance    = $returnid;
        $event->eventtype   = 'due';
        $event->timestart   = $newassignment->timedue;
        $event->timeduration = 0;

        add_event($event);
    }
    
    return $returnid;
}


function newassignment_update_instance($newassignment) {
// Given an object containing all the necessary data, 
// (defined by the form in mod.html) this function 
// will update an existing instance with new data.


    $newassignment->timemodified = time();
    $newassignment->timedue = make_timestamp($newassignment->dueyear, $newassignment->duemonth, $newassignment->dueday, 
                                          $newassignment->duehour, $newassignment->dueminute);
    $newassignment->id = $newassignment->instance;

    if ($returnid = update_record("newassignment", $newassignment)) {

        $event = NULL;

        if ($event->id = get_field('event', 'id', 'modulename', 'newassignment', 'instance', $newassignment->id)) {

            $event->name        = $newassignment->name;
            $event->description = $newassignment->description;
            $event->timestart   = $newassignment->timedue;

            update_event($event);
        }
    }

    return $returnid;
}


function newassignment_delete_instance($id) {
// Given an ID of an instance of this module, 
// this function will permanently delete the instance 
// and any data that depends on it.  

    if (! $newassignment = get_record("newassignment", "id", "$id")) {
        return false;
    }

    $result = true;

    if (! delete_records("newassignment_submissions", "newassignment", "$newassignment->id")) {
        $result = false;
    }

    if (! delete_records("newassignment", "id", "$newassignment->id")) {
        $result = false;
    }

    if (! delete_records('event', 'modulename', 'newassignment', 'instance', $newassignment->id)) {
        $result = false;
    }

    return $result;
}


function newassignment_refresh_events($courseid = 0) {
// This standard function will check all instances of this module
// and make sure there are up-to-date events created for each of them.
// If courseid = 0, then every assignment event in the site is checked, else
// only assignment events belonging to the course specified are checked.
// This function is used, in its new format, by restore_refresh_events()

    if ($courseid == 0) {
        if (! $newassignments = get_records("newassignment")) {
            return true;
        }
    } else {
        if (! $newassignments = get_records("newassignment", "course", $courseid)) {
            return true;
        }
    }
    $moduleid = get_field('modules', 'id', 'name', 'newassignment');

    foreach ($newassignments as $newassignment) {
        $event = NULL;
        $event->name        = addslashes($newassignment->name);
        $event->description = addslashes($newassignment->description);
        $event->timestart   = $newassignment->timedue;

        if ($event->id = get_field('event', 'id', 'modulename', 'newassignment', 'instance', $newassignment->id)) {
            update_event($event);

        } else {
            $event->courseid    = $newassignment->course;
            $event->groupid     = 0;
            $event->userid      = 0;
            $event->modulename  = 'newassignment';
            $event->instance    = $newassignment->id;
            $event->eventtype   = 'due';
            $event->timeduration = 0;
            $event->visible     = get_field('course_modules', 'visible', 'module', $moduleid, 'instance', $newassignment->id);
            add_event($event);
        }

    }
    return true;
}



function newassignment_user_outline($course, $user, $mod, $newassignment) {
    if ($submission = newassignment_get_submission($newassignment, $user)) {
        
        if ($submission->grade) {
            $result->info = get_string("grade").": $submission->grade";
        }
        $result->time = $submission->timemodified;
        return $result;
    }
    return NULL;
}

function newassignment_user_complete($course, $user, $mod, $newassignment) {
    $teachers = get_course_teachers($course->id);
    if ($submission = newassignment_get_submission($newassignment, $user)) {
        if ($basedir = newassignment_file_area($newassignment, $user)) {
            if ($files = get_directory_list($basedir)) {
                $countfiles = count($files)." ".get_string("uploadedfiles", "newassignment");
                foreach ($files as $file) {
                    $countfiles .= "; $file";
                }
            }
        }

        print_simple_box_start();
        echo "<p><font size=1>";
        echo get_string("lastmodified").": ";
        echo userdate($submission->timemodified);
        echo newassignment_print_difference($newassignment->timedue - $submission->timemodified);
        echo "</font></p>";

        newassignment_print_user_files($newassignment, $user);

        echo "<br />";

        if (empty($submission->timemarked)) {
            print_string("notgradedyet", "newassignment");
        } else {
            newassignment_print_feedback($course, $newassignment, $user, $teachers, $submission);
        }

        print_simple_box_end();

    } else {
        print_string("notsubmittedyet", "newassignment");
    }
}


function newassignment_cron () {
// Function to be run periodically according to the moodle cron
// Finds all newassignment notifications that have yet to be mailed out, and mails them

    global $CFG, $USER;

    $cutofftime = time() - $CFG->maxeditingtime;

    if ($submissions = newassignment_get_unmailed_submissions($cutofftime)) {
        $timenow = time();

        foreach ($submissions as $submission) {

            echo "Processing newassignment submission $submission->id\n";
    
            if (! $user = get_record("user", "id", "$submission->userid")) {
                echo "Could not find user $post->userid\n";
                continue;
            }
    
            $USER->lang = $user->lang;
    
            if (! $course = get_record("course", "id", "$submission->course")) {
                echo "Could not find course $submission->course\n";
                continue;
            }
    
            if (! isstudent($course->id, $user->id) and !isteacher($course->id, $user->id)) {
                echo "$user->firstname $user->lastname not an active participant in $course->shortname\n";
                continue;
            }
    
            if (! $teacher = get_record("user", "id", "$submission->teacher") AND ! $fteacher = get_record("user", "id", "$submission->feedbackfileteacher")) {
                echo "Could not find marking/commenting teacher $submission->teacher OR feedbacking teacher $submission->feedbackfileteacher\n";
                continue;
            }
    
            if (! $mod = get_coursemodule_from_instance("newassignment", $submission->newassignment, $course->id)) {
                echo "Could not find course module for newassignment id $submission->newassignment\n";
                continue;
            }
    
            $strnewassignments = get_string("modulenameplural", "newassignment");
            $strnewassignment  = get_string("modulename", "newassignment");
    
            unset($newassignmentinfo);
            
            if ($teacher) {
                $newassignmentinfo->teacher = "$teacher->firstname $teacher->lastname";
            } elseif ($fteacher) {
                $newassignmentinfo->teacher = "$fteacher->firstname $fteacher->lastname";
            }
    
            $newassignmentinfo->newassignment = "$submission->name";
            $newassignmentinfo->url = "$CFG->wwwroot/mod/newassignment/view.php?id=$mod->id";
    
            $postsubject = "$course->shortname: $strnewassignments: $submission->name";
            $posttext  = "$course->shortname -> $strnewassignments -> $submission->name\n";
            $posttext .= "---------------------------------------------------------------------\n";
            $posttext .= get_string("newassignmentmail", "newassignment", $newassignmentinfo);
            $posttext .= "\n---------------------------------------------------------------------\n";
    
            if ($user->mailformat == 1) {  // HTML
                $posthtml = "<p><font face=\"sans-serif\">".
                "<a href=\"$CFG->wwwroot/course/view.php?id=$course->id\">$course->shortname</a> ->".
                "<a href=\"$CFG->wwwroot/mod/newassignment/index.php?id=$course->id\">$strnewassignments</a> ->".
                "<a href=\"$CFG->wwwroot/mod/newassignment/view.php?id=$mod->id\">$submission->name</a></font></p>";
                $posthtml .= "<hr><font face=\"sans-serif\">";
                $posthtml .= "<p>".get_string("newassignmentmailhtml", "newassignment", $newassignmentinfo)."</p>";
                $posthtml .= "</font><hr>";
            } else {
                $posthtml = "";
            }
          
            if (!$teacher AND $fteacher) {
                $teacher = $fteacher;
            }
          
            if (! email_to_user($user, $teacher, $postsubject, $posttext, $posthtml)) {
                echo "Error: newassignment cron: Could not send out mail for id $submission->id to user $user->id ($user->email)\n";
            }
            if (! set_field("newassignment_submissions", "mailed", "1", "id", "$submission->id")) {
                echo "Could not update the mailed field for id $submission->id\n";
            }
        }
    }

    return true;
}

function newassignment_print_recent_activity($course, $isteacher, $timestart) {
    global $CFG;

    $content = false;
    $newassignments = NULL;

    if (!$logs = get_records_select("log", "time > '$timestart' AND ".
        "course = '$course->id' AND ".
        "module = 'newassignment' AND ".
        "action = 'upload' ", "time ASC")) {
        return false;
    }

    foreach ($logs as $log) {
        //Create a temp valid module structure (course,id)
        $tempmod->course = $log->course;
        $tempmod->id = $log->info;
        //Obtain the visible property from the instance
        $modvisible = instance_is_visible($log->module,$tempmod);
         
        //Only if the mod is visible
        if ($modvisible) {
            $newassignments[$log->info] = newassignment_log_info($log);
            $newassignments[$log->info]->time = $log->time;
            $newassignments[$log->info]->url  = $log->url;
        }
    }

    if ($newassignments) {
        $strftimerecent = get_string("strftimerecent");
        $content = true;
        print_headline(get_string("newsubmissions", "newassignment").":");
        foreach ($newassignments as $newassignment) {
            $date = userdate($newassignment->time, $strftimerecent);
            echo "<p><font size=1>$date - $newassignment->firstname $newassignment->lastname<br>";
            echo "\"<a href=\"$CFG->wwwroot/mod/newassignment/$newassignment->url\">";
            echo "$newassignment->name";
            echo "</a>\"</font></p>";
        }
    }
   
    return $content;
}

function newassignment_grades($newassignmentid) {
/// Must return an array of grades, indexed by user, and a max grade.


    if (!$newassignment = get_record("newassignment", "id", $newassignmentid)) {
        return NULL;
    }

    $grades = get_records_menu("newassignment_submissions", "newassignment", 
              $newassignment->id, "", "userid,grade");

    if ($newassignment->grade >= 0) {
        $return->grades = $grades;
        $return->maxgrade = $newassignment->grade;
    } else {
        $scaleid = - ($newassignment->grade);
        if ($scale = get_record("scale", "id", $scaleid)) {
            $scalegrades = make_menu_from_list($scale->scale);
                if ($grades) {
                    foreach ($grades as $key => $grade) {
                        $grades[$key] = $scalegrades[$grade];
                    }
                 }
        }
        $return->grades = $grades;
        $return->maxgrade = "";
    }

    return $return;
}

function newassignment_get_participants($newassignmentid) {
//Returns the users with data in one newassignment
//(users with records in newassignment_submissions, students and teachers)

    global $CFG;

    //Get students
    $students = get_records_sql("SELECT DISTINCT u.*
        FROM {$CFG->prefix}user u,
             {$CFG->prefix}newassignment_submissions a
        WHERE a.newassignment = '$newassignmentid' and
              u.id = a.userid");
    //Get teachers
    $teachers = get_records_sql("SELECT DISTINCT u.*
        FROM {$CFG->prefix}user u,
             {$CFG->prefix}newassignment_submissions a
        WHERE a.newassignment = '$newassignmentid' and
              u.id = a.teacher");

    //Add teachers to students
    if ($teachers) {
        foreach ($teachers as $teacher) {
            $students[$teacher->id] = $teacher;
        }
    }
    //Return students array (it contains an array of unique users)
    return ($students);
}

/// SQL STATEMENTS //////////////////////////////////////////////////////////////////

function newassignment_log_info($log) {
    global $CFG;
    return get_record_sql("SELECT a.name, u.firstname, u.lastname
           FROM {$CFG->prefix}newassignment a, 
           {$CFG->prefix}user u
           WHERE a.id = '$log->info' 
           AND u.id = '$log->userid'");
}


function newassignment_count_real_submissions($newassignment, $groupid=0) {
/// Return all real assignment submissions by ENROLLED students (not empty ones)
    global $CFG;

    if ($groupid) {     /// How many in a particular group?
        return count_records_sql("SELECT COUNT(DISTINCT g.userid, g.groupid)
                                     FROM {$CFG->prefix}newassignment_submissions a,
                                          {$CFG->prefix}groups_members g
                                    WHERE a.newassignment = $newassignment->id 
                                      AND a.timemodified > 0
                                      AND g.groupid = '$groupid' 
                                      AND a.userid = g.userid ");
    } else {                                  
        return count_records_sql("SELECT COUNT(*)
                                  FROM {$CFG->prefix}newassignment_submissions a, 
                                       {$CFG->prefix}user_students s
                                 WHERE a.newassignment = '$newassignment->id' 
                                   AND a.timemodified > 0
                                   AND s.course = '$newassignment->course'
                                   AND a.userid = s.userid ");
    }
} 


function newassignment_get_all_submissions($newassignment, $sort="", $dir="DESC") {
/// Return all newassignment submissions by ENROLLED students
    global $CFG;

    if ($sort == "lastname" or $sort == "firstname") {
        $sort = "u.$sort $dir";
    } else if (empty($sort)) {
        $sort = "a.timemodified DESC";
    } else {
        $sort = "a.$sort $dir";
    }

    return get_records_sql("SELECT a.* 
           FROM {$CFG->prefix}newassignment_submissions a, 
           {$CFG->prefix}user_students s,
           {$CFG->prefix}user u
           WHERE a.userid = s.userid
             AND u.id = a.userid
             AND s.course = '$newassignment->course'
             AND a.newassignment = '$newassignment->id' 
           ORDER BY $sort");
}


function newassignment_get_all_others_submissions($newassignment,$sort, $dir) {
/// Return all newassignment submissions by other thab viweing student
    global $CFG, $USER;

    if ($sort == "lastname" or $sort == "firstname") {
        $sort = "u.$sort $dir";
    } else if (empty($sort)) {
        $sort = "a.grade DESC";
    } else {
        $sort = "a.$sort $dir";
    }

    return get_records_sql("SELECT a.* 
           FROM {$CFG->prefix}newassignment_submissions a, 
           {$CFG->prefix}user_students s,
           {$CFG->prefix}user u
           WHERE a.userid = s.userid
             AND u.id = a.userid
             AND s.course = '$newassignment->course'
             AND a.newassignment = '$newassignment->id' 
                 AND a.timemodified > 0
                 AND a.userid != '$USER->id'
          ORDER BY $sort");
}


function newassignment_get_users_done($newassignment) {
/// Return list of users who have done an newassignment
    global $CFG;
    return get_records_sql("SELECT u.* 
           FROM {$CFG->prefix}user u, 
           {$CFG->prefix}user_students s, 
           {$CFG->prefix}newassignment_submissions a
           WHERE s.course = '$newassignment->course' 
             AND s.userid = u.id
             AND u.id = a.userid 
             AND a.newassignment = '$newassignment->id'
           ORDER BY a.timemodified DESC");
}

function newassignment_get_unmailed_submissions($cutofftime) {
/// Return list of marked submissions that have not been mailed out for currently enrolled students
    global $CFG;
    return get_records_sql("SELECT s.*, a.course, a.name
           FROM {$CFG->prefix}newassignment_submissions s, 
           {$CFG->prefix}newassignment a,
           {$CFG->prefix}user_students us
           WHERE s.mailed = 0 
             AND ((s.timemarked < $cutofftime AND s.timemarked > 0) OR (s.feedbackfile > 0 AND s.feedbacktimeuploaded > 0))
             AND s.newassignment = a.id
             AND s.userid = us.userid
             AND a.course = us.course");
}

//////////////////////////////////////////////////////////////////////////////////////

function newassignment_file_area_name($newassignment, $user) {
//  Creates a directory file name, suitable for make_upload_directory()
    global $CFG;

    return "$newassignment->course/$CFG->moddata/newassignment/$newassignment->id/$user->id";
}

function newassignment_file_area($newassignment, $user) {
    return make_upload_directory( newassignment_file_area_name($newassignment, $user) );
}


function newassignment_feedback_file_area_name($newassignment, $studentid, $user) {
//  Creates a directory file name, suitable for make_upload_directory()
    global $CFG;

    return "$newassignment->course/$CFG->moddata/newassignment/$newassignment->id/$studentid/feedback/$user->id";
}

function newassignment_feedback_file_area($newassignment, $studentid, $user) {
    return make_upload_directory( newassignment_feedback_file_area_name($newassignment, $studentid, $user) );
}


function newassignment_get_submission($newassignment, $user) {
    $submission = get_record("newassignment_submissions", "newassignment", $newassignment->id, "userid", $user->id);
    if (!empty($submission->timemodified)) {
        return $submission;
    }
    return NULL;
}

function newassignment_print_difference($time) {
    if ($time < 0) {
        $timetext = get_string("late", "newassignment", format_time($time));
        return " (<FONT COLOR=RED>$timetext</FONT>)";
    } else {
        $timetext = get_string("early", "newassignment", format_time($time));
        return " ($timetext)";
    }
}

function newassignment_print_submission($newassignment, $user, $submission, $teachers, $grades) {
    global $THEME, $USER;

    echo "\n<TABLE BORDER=1 CELLSPACING=0 width=65% valign=top cellpadding=10 align=center>";

    echo "\n<TR>";
    if ($newassignment->type == NEW_OFFLINE) {
        echo "\n<TD BGCOLOR=\"$THEME->body\" WIDTH=35 VALIGN=TOP>";
    } else {
        echo "\n<TD ROWSPAN=2 BGCOLOR=\"$THEME->body\" WIDTH=35 VALIGN=TOP>";
    }
    print_user_picture($user->id, $newassignment->course, $user->picture);
    echo "</TD>";
    echo "<TD NOWRAP BGCOLOR=\"$THEME->cellheading\">$user->firstname $user->lastname";
    if ($newassignment->type != NEW_OFFLINE and $submission->timemodified) {
        echo "&nbsp;&nbsp;<FONT SIZE=1>".get_string("lastmodified").": ";
        echo userdate($submission->timemodified);
        echo newassignment_print_difference($newassignment->timedue - $submission->timemodified);
        echo "</FONT>";
    }
    echo "</TR>";

    if ($newassignment->type != NEW_OFFLINE) {
        echo "\n<TR><TD BGCOLOR=\"$THEME->cellcontent\">";
        if ($submission->timemodified) {
            newassignment_print_user_files($newassignment, $user);
    } else {
        print_string("notsubmittedyet", "newassignment");
    }
    echo "</TD></TR>";
      }
  
    if (!$submission->teacher) {
        $submission->teacher = $USER->id;
    }

//Print row with feedback file
    echo "\n<TR>";
    echo "<TD WIDTH=35 VALIGN=TOP>";
    if ($submission->feedbackfile) {
        print_user_picture($submission->feedbackfileteacher, $newassignment->course, $teachers[$submission->feedbackfileteacher]->picture);
    } else {
        print_user_picture($USER->id, $newassignment->course, $teachers[$USER->id]->picture);
    }

    if ($submission->timemodified > $submission->feedbacktimeuploaded or (!$submission->timemodified and !$submission->feedbacktimeuploaded)) {
        echo "<TD BGCOLOR=\"$THEME->cellheading2\">";
    } else {
        echo "<TD BGCOLOR=\"$THEME->cellheading\">";
    }
    echo get_string("feedbackfile", "newassignment").": ";

    if ($submission->feedbacktimeuploaded) {
        newassignment_print_feedback_files($newassignment, $user, $teachers, $submission);
        echo "&nbsp;&nbsp;<FONT SIZE=1>".userdate($submission->feedbacktimeuploaded)."</FONT>";
    } else {
        print_string("notsubmittedfeedbackyet", "newassignment");
    }

    echo "  [ ";
    link_to_popup_window("/mod/newassignment/feedbackupl.php?id=$newassignment->id&studentid=$user->id",
               "feedback", get_string("uploadfeedbackfile", "newassignment"), 150, 600);
    echo "]<br>\n</TD></TR>";

//Print row with rating and/or comment
    echo "\n<TR>";
    echo "<TD WIDTH=35 VALIGN=TOP>";
    print_user_picture($submission->teacher, $newassignment->course, $teachers[$submission->teacher]->picture);
    if ($submission->timemodified > $submission->timemarked or (!$submission->timemodified and !$submission->timemarked)) {
        echo "<TD BGCOLOR=\"$THEME->cellheading2\">";
    } else {
        echo "<TD BGCOLOR=\"$THEME->cellheading\">";
    }
    echo get_string("feedback", "newassignment").":";
    choose_from_menu($grades, "g$submission->id", $submission->grade, get_string("nograde"));
    if ($submission->timemarked) {
        echo "&nbsp;&nbsp;<FONT SIZE=1>".userdate($submission->timemarked)."</FONT>";
    }
    echo "<BR><TEXTAREA NAME=\"c$submission->id\" ROWS=4 COLS=60 WRAP=virtual>";
    p($submission->comment);
    echo "</TEXTAREA><BR>";
    echo "</TD></TR>";
    echo "</TABLE><BR CLEAR=ALL>\n";
}

function newassignment_print_feedback($course, $newassignment, $user, $teachers, $submission) {
// prints feedback and feedback files for the student

    global $CFG, $THEME, $RATING;

    if (!$teacher = get_record("user", "id", $submission->teacher) and !$teacher = get_record("user", "id", $submission->feedbackfileteacher)) {
        error("Weird newassignment error");
    }

    echo "\n<TABLE BORDER=0 CELLPADDING=1 CELLSPACING=1 ALIGN=CENTER><TR><TD BGCOLOR=#888888>";
    echo "\n<TABLE BORDER=0 CELLPADDING=3 CELLSPACING=0 VALIGN=TOP>";

    echo "\n<TR>";
    echo "\n<TD ROWSPAN=3 BGCOLOR=\"$THEME->body\" WIDTH=35 VALIGN=TOP>";
    print_user_picture($teacher->id, $course->id, $teacher->picture);
    echo "</TD>";
    echo "<TD NOWRAP WIDTH=100% BGCOLOR=\"$THEME->cellheading\">$teacher->firstname $teacher->lastname";
    echo "&nbsp;&nbsp;<FONT SIZE=2><I>".userdate($submission->timemarked)."</I>";
    echo "</TR>";

    echo "\n<TR><TD WIDTH=100% BGCOLOR=\"$THEME->cellcontent\">";

    echo "<P ALIGN=RIGHT><FONT SIZE=-1><I>";
    if ($submission->grade) {
        echo get_string("grade").": $submission->grade";
    } else {
        echo get_string("nograde");
    }
    echo "</I></FONT></P>";

    echo text_to_html($submission->comment);
    echo "</TD></TR>";
    if ($newassignment->type == NEW_OFFLINE || ($submission->timemodified < $submission->feedbacktimeuploaded)) {  // print the feedback file only if uploaded after s student's submission
        echo "\n<TR><TD WIDTH=100% BGCOLOR=\"$THEME->cellheading\" ALIGN=CENTER>";
        newassignment_print_feedback_files ($newassignment, $user, $teachers, $submission);
        echo "</TD></TR>";
    }
    echo "</TABLE>";
    echo "</TD></TR></TABLE>";
}


function newassignment_print_user_files($newassignment, $user, $exception="feedback") {   //CHANGED CODE
// Arguments are objects

    global $CFG, $THEME;

    $filearea = newassignment_file_area_name($newassignment, $user);

    if ($basedir = newassignment_file_area($newassignment, $user)) {
        if ($files = get_directory_list($basedir, $exception)) {  //CHANGED CODE
            foreach ($files as $file) {
                $icon = mimeinfo("icon", $file);
                if ($CFG->slasharguments) {
                    $ffurl = "file.php/$filearea/$file";
                } else {
                    $ffurl = "file.php?file=/$filearea/$file";
                }

                echo "<IMG SRC=\"$CFG->wwwroot/pix/f/$icon\" HEIGHT=16 WIDTH=16 BORDER=0 ALT=\"File\">";
                echo "&nbsp;<A TARGET=\"uploadedfile\" HREF=\"$CFG->wwwroot/$ffurl\">$file</A>&nbsp;&nbsp;&nbsp;";
                echo "<BR>";
            }
        }
    }
}


function newassignment_print_feedback_files($newassignment, $user, $teachers, $submission, $printall=false) {
// Arguments are objects

    global $CFG, $THEME;

  if ($printall==false) {
    $studentid = $user->id;
    $user = $teachers[$submission->feedbackfileteacher];
  } else {
    $studentid = $user->id;
    $user = $teachers[$submission->teacher];
  }

    $filearea = newassignment_feedback_file_area_name($newassignment, $studentid, $user);
    if ($basedir = newassignment_feedback_file_area($newassignment, $studentid, $user)) {
        if ($files = get_directory_list($basedir)) {
            foreach ($files as $file) {
                $icon = mimeinfo("icon", $file);
                if ($CFG->slasharguments) {
                    $ffurl = "file.php/$filearea/$file";
                } else {
                    $ffurl = "file.php?file=/$filearea/$file";
                }

                echo "<IMG SRC=\"$CFG->wwwroot/pix/f/$icon\" HEIGHT=16 WIDTH=16 BORDER=0 ALT=\"File\">";
                echo "&nbsp;<A TARGET=\"uploadedfile\" HREF=\"$CFG->wwwroot/$ffurl\">$file</A>&nbsp;&nbsp;&nbsp;";
            }
        }
    }
}


function newassignment_delete_user_files($newassignment, $user, $exception) {
// Deletes all the user files in the newassignment area for a user
// EXCEPT for any file named $exception

    if ($basedir = newassignment_file_area($newassignment, $user)) {
        if ($files = get_directory_list($basedir, "feedback")) {
            foreach ($files as $file) {
                if ($file != $exception) {
                    unlink("$basedir/$file");
                    notify("Existing file '$file' has been deleted!");
                }
            }
        }
    }
}


function newassignment_delete_feedback_files($newassignment, $studentid, $user, $exception) {
// Deletes all the user files in the newassignment area for a user
// EXCEPT for any file named $exception

    if ($basedir = newassignment_feedback_file_area($newassignment, $studentid, $user)) {
        if ($files = get_directory_list($basedir)) {
            foreach ($files as $file) {
                if ($file != $exception) {
                    unlink("$basedir/$file");
                    notify("Existing file '$file' has been deleted!");
                }
            }
        }
    }
}


function newassignment_print_upload_form($newassignment) {
// Arguments are objects

    echo "<DIV ALIGN=CENTER>";
    echo "<FORM ENCTYPE=\"multipart/form-data\" METHOD=\"POST\" ACTION=upload.php>";
    echo " <INPUT TYPE=hidden NAME=MAX_FILE_SIZE value=\"$newassignment->maxbytes\">";
    echo " <INPUT TYPE=hidden NAME=id VALUE=\"$newassignment->id\">";
    echo " <INPUT NAME=\"newfile\" TYPE=\"file\" size=\"50\">";
    echo " <INPUT TYPE=submit NAME=save VALUE=\"".get_string("uploadthisfile")."\">";
    echo "</FORM>";
    echo "</DIV>";
}


function newassignment_print_others_assignments($newassignment, $user, $submission) {
//If allowed by teacher prints other students' assignments

    global $THEME, $USER;

    echo "\n<TR>\n<TD ROWSPAN=2 BGCOLOR=\"$THEME->body\" WIDTH=35 VALIGN=TOP>";
    print_user_picture($user->id, $newassignment->course, $user->picture);
    echo "</TD>";
    echo "<TD NOWRAP BGCOLOR=\"$THEME->cellheading\">$user->firstname $user->lastname";
    if ($newassignment->type != NEW_OFFLINE and $submission->timemodified) {
        echo "&nbsp;&nbsp;<FONT SIZE=1>".get_string("lastmodified").": ";
        echo userdate($submission->timemodified);
        echo newassignment_print_difference($newassignment->timedue - $submission->timemodified);
        echo "</FONT>";
    }
    echo "</TR>";

    if ($newassignment->type != NEW_OFFLINE) {
        echo "\n<TR><TD BGCOLOR=\"$THEME->cellcontent\">";
        if ($submission->timemodified) {
            newassignment_print_user_files($newassignment, $user);
        } else {
            print_string("notsubmittedyet", "newassignment");
        }
        echo "</TD></TR>";
    }
}

function newassignment_print_feedback_upload_form($newassignment, $studentid, $teacherid) {
// Arguments are objects

    echo "<DIV ALIGN=CENTER>";
    echo "<FORM ENCTYPE=\"multipart/form-data\" METHOD=\"POST\" ACTION=upload.php>";
    echo " <INPUT TYPE=hidden NAME=MAX_FILE_SIZE value=\"$newassignment->maxbytes\">";
    echo " <INPUT TYPE=hidden NAME=id VALUE=\"$newassignment->id\">";
    echo " <INPUT TYPE=hidden NAME=studentid VALUE=\"$studentid\">";
    echo " <INPUT TYPE=hidden NAME=teacherid VALUE=\"$teacherid\">";
    echo " <INPUT TYPE=hidden NAME=feedbackfile VALUE=false>";
    echo " <INPUT NAME=\"newfile\" TYPE=\"file\" size=\"50\"><br>";
    echo " <INPUT TYPE=submit NAME=save VALUE=\"".get_string("uploadthisfile")."\">";
    echo "</FORM>";
    echo "</DIV>";
}

function newassignment_print_close($link) {

    if (!$link) {
        $link = $_SERVER["HTTP_REFERER"];
    }

    print_heading("<a href=\"$link\" onClick=\"self.close()\">".get_string("closewindow")."</a>");
  echo "\n</body>\n</html>";
}

?>